==> aria2-1.8.3.tar.bz2: aria2-1.8.3/src/DHTResponseMessage.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "DHTResponseMessage.h"
#include "DHTNode.h"
#include "util.h"
#include "bencode.h"
#include "a2functional.h"

namespace aria2 {

const std::string DHTResponseMessage::R("r");

DHTResponseMessage::DHTResponseMessage(const SharedHandle<DHTNode>& localNode,
                                       const SharedHandle<DHTNode>& remoteNode,
                                       const std::string& transactionID):
  DHTAbstractMessage(localNode, remoteNode, transactionID) {}

DHTResponseMessage::~DHTResponseMessage() {}

std::string DHTResponseMessage::getType() const
{
  return R;
}

void DHTResponseMessage::fillMessage(BDE& msgDict)
{
  msgDict[R] = getResponse();
}

bool DHTResponseMessage::isReply() const
{
  return true;
}

std::string DHTResponseMessage::toString() const
{
  return strconcat("dht response ", getMessageType(),
                   " TransactionID=", util::toHex(_transactionID),
                   " Remote:", _remoteNode->getIPAddress(),
                   ":", util::uitos(_remoteNode->getPort()),
                   ", id=", util::toHex(_remoteNode->getID(), DHT_ID_LENGTH),
                   ", ", toStringOptional());
}

} // namespace aria2

==> aria2_1.9.4.orig.tar.bz2: aria2-1.9.4/src/DHTResponseMessage.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "DHTResponseMessage.h"
#include "DHTNode.h"
#include "util.h"
#include "bencode.h"
#include "a2functional.h"

namespace aria2 {

const std::string DHTResponseMessage::R("r");

DHTResponseMessage::DHTResponseMessage(const SharedHandle<DHTNode>& localNode,
                                       const SharedHandle<DHTNode>& remoteNode,
                                       const std::string& transactionID):
  DHTAbstractMessage(localNode, remoteNode, transactionID) {}

DHTResponseMessage::~DHTResponseMessage() {}

std::string DHTResponseMessage::getType() const
{
  return R;
}

void DHTResponseMessage::fillMessage(BDE& msgDict)
{
  msgDict[R] = getResponse();
}

bool DHTResponseMessage::isReply() const
{
  return true;
}

std::string DHTResponseMessage::toString() const
{
  std::string s = strconcat
    ("dht response ", getMessageType(),
     " TransactionID=", util::toHex(_transactionID),
     " Remote:", _remoteNode->getIPAddress(),
     ":", util::uitos(_remoteNode->getPort()),
     ", id=", util::toHex(_remoteNode->getID(), DHT_ID_LENGTH),
     ", ");
  if(!_version.empty()) {
    s += "v=";
    s += util::torrentPercentEncode(_version);
    s += ", ";
  }
  s += toStringOptional();
  return s;
}

} // namespace aria2
